from setuptools import setup, find_packages

setup(
    name="hn_async",
    version="0.1",
    packages=find_packages(where="src"),
    package_dir={"": "src"},
    install_requires=[
        "aiohttp",
        "tqdm",
    ],
    python_requires=">=3.8",
) 